@@ -780,7 +780,7 @@ computeUnsortedAlphaPalette(FILE *           const ifP,
 
     cht = ppm_colorhisttocolorhash (chv, colors);
 
-    for (color_index = 0 ; color_index < colors + 1 ; ++color_index) {
+    for (color_index = 0 ; color_index < colors ; ++color_index) {
         /* TODO: It sure would be nice if we didn't have to allocate
            256 words here for what is normally only 0 or 1 different
            alpha values!  Maybe we should do some sophisticated reallocation.
@@ -830,6 +830,7 @@ sortAlphaPalette(gray *alphas_of_color[],
                  unsigned int alphas_first_index[],
                  unsigned int alphas_of_color_cnt[],
                  unsigned int const colors,
+                 gray         const alphaMaxval,
                  unsigned int mapping[],
                  unsigned int * const transSizeP) {
 /*----------------------------------------------------------------------------
@@ -862,7 +863,7 @@ sortAlphaPalette(gray *alphas_of_color[],
         for (j = 0; j < alphas_of_color_cnt[colorIndex]; ++j) {
             unsigned int const paletteIndex = 
                 alphas_first_index[colorIndex] + j;
-            if (alphas_of_color[colorIndex][j] == PALETTEOPAQUE)
+            if (alphas_of_color[colorIndex][j] == alphaMaxval)
                 mapping[paletteIndex] = top_idx--;
                 else
                     mapping[paletteIndex] = bot_idx++;
@@ -887,6 +888,7 @@ compute_alpha_palette(FILE *         const ifP,
                       int            const format,
                       pm_filepos     const imagepos,
                       gray **        const alpha_mask,
+                      gray           const alphaMaxval,
                       pixel                palette_pnm[],
                       gray                 trans_pnm[],
                       unsigned int * const paletteSizeP,
@@ -946,7 +948,7 @@ compute_alpha_palette(FILE *         const ifP,
 
         /* Make the opaque palette entries last */
         sortAlphaPalette(alphas_of_color, alphas_first_index,
-                         alphas_of_color_cnt, colors,
+                         alphas_of_color_cnt, colors, alphaMaxval,
                          mapping, transSizeP);
 
         {
@@ -966,7 +968,7 @@ compute_alpha_palette(FILE *         const ifP,
     }
     { 
         unsigned int colorIndex;
-        for (colorIndex = 0; colorIndex < colors + 1; ++colorIndex)
+        for (colorIndex = 0; colorIndex < colors; ++colorIndex)
             free(alphas_of_color[colorIndex]);
     }
 } 
@@ -1164,6 +1166,7 @@ tryAlphaPalette(FILE *         const ifP,
                 int            const format,
                 pm_filepos     const imagepos,
                 gray **        const alpha_mask,
+                gray           const alphaMaxval,
                 FILE *         const pfP,
                 pixel *        const palette_pnm,
                 unsigned int * const paletteSizeP,
@@ -1178,7 +1181,8 @@ tryAlphaPalette(FILE *         const ifP,
                  "the palette with -palette.");
 
     compute_alpha_palette(ifP, cols, rows, maxval, format, 
-                          imagepos,  alpha_mask, palette_pnm, trans_pnm, 
+                          imagepos,  alpha_mask, alphaMaxval,
+                          palette_pnm, trans_pnm, 
                           paletteSizeP, transSizeP, &tooBig);
     if (tooBig) {
         asprintfN(impossibleReasonP,
@@ -1287,6 +1291,7 @@ computeColorMap(FILE *         const ifP,
                 int            const background,
                 pixel          const backcolor,
                 gray **        const alpha_mask,
+                gray           const alphaMaxval,
                 unsigned int   const pnm_meaningful_bits,
                 /* Outputs */
                 pixel *        const palette_pnm,
@@ -1355,7 +1360,8 @@ computeColorMap(FILE *         const ifP,
                     unsigned int transSize;
                     if (alpha)
                         tryAlphaPalette(ifP, cols, rows, maxval, format,
-                                        imagepos, alpha_mask, pfP,
+                                        imagepos, alpha_mask, alphaMaxval,
+                                        pfP,
                                         palette_pnm, &paletteSize, 
                                         trans_pnm, &transSize,
                                         noColormapReasonP);
@@ -1760,7 +1766,7 @@ convertpnm(FILE * const ifp,
   computeColorMap(ifp, imagepos, cols, rows, maxval, format,
                   force, pfp, alpha, transparent >= 0, transcolor, transexact, 
                   background, backcolor,
-                  alpha_mask, pnm_meaningful_bits,
+                  alpha_mask, alpha_maxval, pnm_meaningful_bits,
                   palette_pnm, &palette_size, trans_pnm, &trans_size,
                   &background_index, &noColormapReason);
 
