@@ -418,6 +418,7 @@ dumpX11Header(X11WDFileHeader * const h11P) {
     case GrayScale:   visualClassDesc = "GrayScale";   break;
     case StaticColor: visualClassDesc = "StaticColor"; break;
     case PseudoColor: visualClassDesc = "PseudoColor"; break;
+    case TrueColor:   visualClassDesc = "TrueColor";   break;
     case DirectColor: visualClassDesc = "DirectColor"; break;
     default:          visualClassDesc = "???";
     }
@@ -815,9 +816,9 @@ getpix(FILE *file, struct row_control * const row_controlP,
             bit_shift = row_controlP->bits_used;
 
         if ( bits_to_take == sizeof(bits_to_take_mask) * 8 )
-            bits_to_take_mask = -1;
+            bits_to_take_mask = -1L;
         else
-            bits_to_take_mask = ( 1 << bits_to_take ) - 1;
+            bits_to_take_mask = ( 1L << bits_to_take ) - 1;
         
         switch ( bits_per_item ) {
         case 8:
