@@ -72,7 +72,7 @@ parse_command_line(int argc, char ** argv,
         /* Uses and sets argc, argv, and some of *cmdlineP and others. */
 
     if (argc - 1 == 0)
-        cmdline_p->input_filename = "=";  /* he wants stdin */
+        cmdline_p->input_filename = "-";  /* he wants stdin */
     else if (argc - 1 == 1)
         cmdline_p->input_filename = strdup(argv[1]);
     else 
